Learn R Programming

metanetwork (version 0.7.0)

extract_networks: extract networks from a metanetwork object

Description

Function to extract metawebs and local networks from a metanetwork object

Usage

extract_networks(metanetwork)

Value

a list of igraph objects with attributes computed by metanetwork

Arguments

metanetwork

the object whose networks need to be extracted

Details

Return a list of 'igraph' objects

Examples

Run this code
library(metanetwork)
data("meta_angola")
nets = extract_networks(meta_angola)  
sapply(nets,class)

Run the code above in your browser using DataLab