Learn R Programming

metanetwork (version 0.7.0)

meta_angola: Angola fishery metanetwork metanetwork built from: Angelini & Velho 2011, Data from: Angelini, R., Velho, VF. (2011) Ecosystem structure and trophic analysis of Angolan fishery landings. Scientia Marina 75(2)

Description

Angola fishery metanetwork metanetwork built from: Angelini & Velho 2011, Data from: Angelini, R., Velho, VF. (2011) Ecosystem structure and trophic analysis of Angolan fishery landings. Scientia Marina 75(2)

Usage

data(meta_angola)

Arguments

Format

A object of class 'metanetwork'
metaweb

The metaweb from Angelini & Velho 2011, containing 28 groups and 127 interactions, a igraph object

abTable

Abundance table built from biomass at two dates: 1986 and 2003, a matrix

trophicTable

Taxonomic table, a three column data.frame with three different taxonomic levels (species (or group), phylum and kingdom)