Learn R Programming

metanetwork (version 0.7.0)

meta_norway: Norway soil metanetwork metanetwork built from: Calderon-Sanou et al. 2021, Data from: Calderon-Sanou, I., Munkemuller, T., Zinger, L., Schimann, H., Yoccoz, N. G., Gielly, L., ... & Thuiller, W. (2021). Cascading effects of moth outbreaks on subarctic soil food webs. Scientific reports, 11(1), 1-12.

Description

Norway soil metanetwork metanetwork built from: Calderon-Sanou et al. 2021, Data from: Calderon-Sanou, I., Munkemuller, T., Zinger, L., Schimann, H., Yoccoz, N. G., Gielly, L., ... & Thuiller, W. (2021). Cascading effects of moth outbreaks on subarctic soil food webs. Scientific reports, 11(1), 1-12.

Usage

data(meta_norway)

Arguments

Format

A object of class 'metanetwork'
metaweb

The metaweb from Calderon-Sanou et al. 2021, containing 40 groups and 204 interactions, a igraph object

abTable

Abundance table built from eDNA data in disturbed (moth outbreaks) and non-disturbed sites, a matrix

trophicTable

Trophic table, a three column data.frame with three different taxonomic levels (trophic_group, trophic_class and taxa)