object of class 'metanetwork', with computed layout stored as node attribute
Arguments
metaweb
metaweb of the metanetwork, object of class 'graph', 'matrix', 'data.frame' or 'dgCMatrix'.
Metaweb needs to be directed and connected. This parameter must be non-null.
abTable
abundances of nodes in local networks, matrix of class 'matrix',
columns must have names corresponding to node labels of the metaweb,
rows are node abundances in local networks.
Default is null, in that case, uniform abundances are assigned
trophicTable
a 'matrix' or 'data.frame' indicating hierarchy of the nodes.
Names of the columns correspond to the different resolutions.
It indicates the membership of each node of the metaweb. Default is null.
compute_local_nets
a boolean, indicates whether local networks must be computed or not.
Default is TRUE
verbose
a boolean indicating whether message along the pipeline should be printed
beta
the diffusion parameter of the diffusion kernel, a positive scalar controlling the
squeezing of the network