powered by
Method executing the whole metanetwork pipeline for the initial metanetwork object (append_agg_nets, compute_TL, attach_layout)
append_agg_nets
compute_TL
attach_layout
metanet_pipe(metanetwork, beta = 0.1, verbose = TRUE)# S3 method for metanetwork metanet_pipe(metanetwork, beta = 0.1, verbose = TRUE)
# S3 method for metanetwork metanet_pipe(metanetwork, beta = 0.1, verbose = TRUE)
object of class 'metanetwork', with computed trophic levels and layout stored as node attribute
NULL
object of class 'metanetwork'
the diffusion parameter of the diffusion kernel, a positive scalar controlling the squeezing of the network
a boolean indicating whether message along the pipeline should be printed
library(metanetwork) library(igraph) g = make_lattice(dimvector = c(4,4),2,3,directed = TRUE) meta0 = build_metanet(g) meta0 = metanet_pipe(meta0) ggmetanet(meta0)
Run the code above in your browser using DataLab