powered by
Function to extract metawebs and local networks from a metanetwork object
extract_networks(metanetwork)
a list of igraph objects with attributes computed by metanetwork
igraph
metanetwork
the object whose networks need to be extracted
Return a list of 'igraph' objects
library(metanetwork) data("meta_angola") nets = extract_networks(meta_angola) sapply(nets,class)
Run the code above in your browser using DataLab