- metanetwork
object of class metanetwork
- g
network (igraph object) to represent, default is metaweb
- beta
the diffusion parameter of the diffusion kernel, a positive scalar controlling the
vertical squeezing of the network
- legend
resolution for the legend, legend resolution must be a coarser resolution than the resolution of g, default is NULL
- mode
mode used for layout, 'TL-tsne' for trophic level t-sne. Default is 'TL-tsne'
- edge_thrs
if non-null, a numeric (between 0 and 1) indicating an edge threshold for the representation
- layout_metaweb
a boolean indicating whether the layout of the metaweb should be used to represent the network
to use metaweb layout = T, you need first to compute metaweb layout for this beta value using attach_layout()
- nrep_ly
If several layouts for this beta value are attached to the metaweb (if layout_metaweb = T), index of the layout to use, see attach_layout()
- flip_coords
a boolean indicating whether coordinates should be flipped.
In that case, y-axis is the trophic level and x-axis is the layout axis
- diff_plot_bool
boolean, do not edit by hand
- x_y_range
a two dimension numeric vector, indicating dilatation of x,y axis
- visNetwork.config
configuration list for visNetwork representation, default is visNetwork.default
- TL_tsne.config
configuration list for mode 'TL-tsne', default is TL_tsne.default